DomainRecord class

Constructors

DomainRecord({String? id, required String type, required String name, required String data, int? priority, int? port, int? ttl, int? weight, int? flags, int? tag})
DomainRecord.fromJson(String source)
factory
DomainRecord.fromMap(Map<String, dynamic> map)
factory

Properties

data String
getter/setter pair
flags int?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String?
getter/setter pair
name String
getter/setter pair
port int?
getter/setter pair
priority int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag int?
getter/setter pair
ttl int?
getter/setter pair
type String
getter/setter pair
weight int?
getter/setter pair

Methods

copyWith({String? id, String? type, String? name, String? data, int? priority, int? port, int? ttl, int? weight, int? flags, int? tag}) DomainRecord
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override