DomainSpec class

Constructors

DomainSpec({required String domain, String? type, String? zone, required String minimumTlsVersion})
DomainSpec.fromJson(String source)
factory
DomainSpec.fromMap(Map<String, dynamic> map)
factory

Properties

domain String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
minimumTlsVersion String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
getter/setter pair
zone String?
getter/setter pair

Methods

copyWith({String? domain, String? type, String? zone, String? minimumTlsVersion}) DomainSpec
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override