EnvVariableModel class

Constructors

EnvVariableModel({required String key, String? scope, String? type, required String value})
EnvVariableModel.fromJson(String source)
factory
EnvVariableModel.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
key String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String?
getter/setter pair
type String?
getter/setter pair
value String
getter/setter pair

Methods

copyWith({String? key, String? scope, String? type, String? value}) EnvVariableModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override