ImageSourceSpec class

Constructors

ImageSourceSpec({required String registry, String registryType = "DOCR", required String repository, String tag = "latest", bool autoDeploy = true})
ImageSourceSpec.fromJson(String source)
factory
ImageSourceSpec.fromMap(Map<String, dynamic> map)
factory

Properties

autoDeploy bool
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
registry String
getter/setter pair
registryType String
getter/setter pair
repository String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
getter/setter pair

Methods

copyWith({String? registry, String? registryType, String? repository, String? tag, bool? autoDeploy}) ImageSourceSpec
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override