StaticSiteSpec class

Constructors

StaticSiteSpec({required String name, GitInfos? git, String? environmentSlug, List<EnvVariableModel>? envs, List<Route>? routes, String? indexDocument, String? catchallDocument, String? errorDocument})
StaticSiteSpec.fromJson(String source)
factory
StaticSiteSpec.fromMap(Map<String, dynamic> map)
factory

Properties

catchallDocument String?
getter/setter pair
environmentSlug String?
getter/setter pair
envs List<EnvVariableModel>?
getter/setter pair
errorDocument String?
getter/setter pair
git GitInfos?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
indexDocument String?
getter/setter pair
name String
getter/setter pair
routes List<Route>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, GitInfos? git, String? runCommand, String? environmentSlug, List<EnvVariableModel>? envs, List<Route>? routes, String? indexDocument, String? catchallDocument, String? errorDocument}) StaticSiteSpec
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override