AppSpec class
Constructors
-
AppSpec({required String name, required List<
ServiceSpec> services, String? region, required List<DomainSpec> domains, List<StaticSiteSpec> ? staticSites}) - AppSpec.fromJson(String source)
-
factory
-
AppSpec.fromMap(Map<
String, dynamic> map) -
factory
Properties
-
domains
↔ List<
DomainSpec> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- name ↔ String
-
getter/setter pair
- region ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
services
↔ List<
ServiceSpec> -
getter/setter pair
-
staticSites
↔ List<
StaticSiteSpec> ? -
getter/setter pair
Methods
-
copyWith(
{String? name, List< ServiceSpec> ? services, String? region, List<DomainSpec> ? domains, List<StaticSiteSpec> ? staticSites}) → AppSpec -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override