DomainRecord class
Constructors
-
DomainRecord({String? id, required String type, required String name, required String data, int? priority, int? port, int? ttl, int? weight, int? flags, int? tag})
-
-
DomainRecord.fromJson(String source)
-
factory
-
DomainRecord.fromMap(Map<String, dynamic> map)
-
factory
Methods
-
copyWith({String? id, String? type, String? name, String? data, int? priority, int? port, int? ttl, int? weight, int? flags, int? tag})
→ DomainRecord
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ String
-
-
toMap()
→ Map<String, dynamic>
-
-
toString()
→ String
-
A string representation of this object.
override