Region class
Constructors
Properties
- continent ↔ String
-
getter/setter pair
-
dataCenters
↔ List<
String> -
getter/setter pair
- flag ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- label ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slug ↔ String
-
getter/setter pair
Methods
-
copyWith(
{String? slug, String? label, String? flag, String? continent, List< String> ? dataCenters}) → Region -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override