ServiceSpec class
Constructors
-
ServiceSpec({required String name, GitInfos? git, ImageSourceSpec? image, String? runCommand, String? environmentSlug, required String instanceSizeSlug, required int instanceCount, required int httpPort, List<
Route> ? routes, List<EnvVariableModel> ? envs}) - ServiceSpec.fromJson(String source)
-
factory
-
ServiceSpec.fromMap(Map<
String, dynamic> map) -
factory
Properties
- environmentSlug ↔ String?
-
getter/setter pair
-
envs
↔ List<
EnvVariableModel> ? -
getter/setter pair
- git ↔ GitInfos?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- httpPort ↔ int
-
getter/setter pair
- image ↔ ImageSourceSpec?
-
getter/setter pair
- instanceCount ↔ int
-
getter/setter pair
- instanceSizeSlug ↔ String
-
getter/setter pair
- name ↔ String
-
getter/setter pair
-
routes
↔ List<
Route> ? -
getter/setter pair
- runCommand ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? name, GitInfos? git, ImageSourceSpec? image, String? runCommand, String? environmentSlug, String? instanceSizeSlug, int? instanceCount, int? httpPort, List< Route> ? routes, List<EnvVariableModel> ? envs}) → ServiceSpec -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override